[][src]Enum mief::elements::player::FieldSide

pub enum FieldSide {
    Left,
    Right,
}

The player's position on the field.

Variants

Left

The player plays on the left side of the field.

Right

The player plays on the right side of the field.

Methods

impl FieldSide[src]

pub fn get_x_position(&self, player_width: f64, field_width: u32) -> f64[src]

Get the x position on the field, depending on the field size.